=================================================================
:mod:`cloud_sptheme.ext.relbar_toc` - adds TOC entry to relbar
=================================================================

.. module:: cloud_sptheme.ext.relbar_toc
    :synopsis: adds TOC entry to right side of relbar

.. deprecated:: 1.8.1

    This extension is now an alias for :mod:`cloud_sptheme.ext.relbar_links`.
    This alias will be removed at some point in the future.
